]> cloudbase.mooo.com Git - z180-stamp.git/blobdiff - avr/cli.c
Rename getenv() to getenv_char()
[z180-stamp.git] / avr / cli.c
index 6b26b6f09cc77d09542271af3eb54999837f9379..8763ed1dff7a775c59af2522ed29d0e2ed5ec4a2 100644 (file)
--- a/avr/cli.c
+++ b/avr/cli.c
@@ -44,9 +44,7 @@ static int cli_parse_line(char *line, char *argv[])
 
        debug_parser("%s: \"%s\"\n", __func__, line);
 
-       for (outp = inp = line, quote = '\0' ;
-                       nargs < CONFIG_SYS_MAXARGS && (c = *inp) != '\0';
-                       inp++) {
+       for (outp = inp = line, quote = '\0'; (c = *inp) != '\0'; inp++) {
 
                switch (state) {
                case 0:                                         /* before arg string, waiting for arg start */
@@ -91,6 +89,11 @@ static int cli_parse_line(char *line, char *argv[])
                        break;
 
                }
+
+               if (nargs > CONFIG_SYS_MAXARGS) {
+                       --nargs;
+                       break;
+               }
                *outp++ = c;
        }
 
@@ -174,7 +177,7 @@ char *process_macros(char *input, char *output)
                                if (c == '}') {
                                        /* Terminate variable name */
                                        *(inp-1) = '\0';
-                                       const char *envval = getenv(varname);
+                                       const char *envval = getenv_char(varname);
                                        *(inp-1) = '}';
                                        /* Copy into the line if it exists */
                                        if (envval != NULL)
@@ -207,7 +210,7 @@ char *process_macros(char *input, char *output)
  * WARNING:
  *
  * We must create a temporary copy of the command since the command we get
* may be the result from getenv(), which returns a pointer directly to
  * the environment data, which may change magicly when the command we run
  * creates or modifies environment variables (like "bootp" does).
  *
@@ -313,7 +316,7 @@ static int cli_run_command_list(const char *cmd)
 
 
 /*
- * Run a command using the selected parser.
+ * Run a command.
  *
  * @param cmd  Command to run
  * @param flag Execution flags (CMD_FLAG_...)
@@ -395,9 +398,9 @@ command_ret_t do_run(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
        for (i = 1; i < argc; ++i) {
                char *arg;
 
-               arg = getenv(argv[i]);
+               arg = getenv_char(argv[i]);
                if (arg == NULL) {
-                       printf_P(PSTR("## Error: \"%s\" not defined\n"), argv[i]);
+                       printf_P(PSTR("## Error: \"%s\" is not set\n"), argv[i]);
                        return CMD_RET_FAILURE;
                }
@@ -207,7 +210,7 @@ char *process_macros(char *input, char *output)
  *
  * We must create a temporary copy of the command since the command we get
- * may be the result from getenv(), which returns a pointer directly to
+ * may be the result from getenv_char(), which returns a pointer directly to
  * the environment data, which may change magicly when the command we run
  * creates or modifies environment variables (like "bootp" does).